@@ -31,7 +31,7 @@ namespace GpgME {
 
   class GPGMEPP_EXPORT Error {
   public:
-    explicit Error( int e=0 ) : mErr( e ) {}
+    explicit Error( unsigned int e=0 ) : mErr( e ) {}
 
     const char * source() const;
     const char * asString() const;
@@ -41,10 +41,15 @@ namespace GpgME {
 
     bool isCanceled() const;
 
-    operator int() const { return mErr; }
-    operator bool() const { return mErr && !isCanceled(); }
+    operator unsigned int() const { return mErr; }
+
   private:
-    int mErr;
+    struct __safe_bool_dummy__ { void nonnull() {} };
+    typedef void ( __safe_bool_dummy__::*unspecified_bool_type )();
+  public:
+    operator unspecified_bool_type() const { return mErr && !isCanceled() ? &__safe_bool_dummy__::nonnull : 0 ; }
+  private:
+    unsigned int mErr;
   };
 
 } // namespace GpgME
