@@ -19,14 +19,12 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef KABC_RESOURCELDAP_H
-#define KABC_RESOURCELDAP_H
+#ifndef KABC_RESOURCELDAPKIO_H
+#define KABC_RESOURCELDAPKIO_H
 
 #include <kio/job.h>
 #include "kabc/resource.h"
 
-class KConfig;
-
 namespace KABC {
 
 class KABC_LDAPKIO_EXPORT ResourceLDAPKIO : public Resource
@@ -34,32 +32,37 @@ class KABC_LDAPKIO_EXPORT ResourceLDAPKIO : public Resource
   Q_OBJECT
 
   public:
-    enum CachePolicy{ Cache_No, Cache_NoConnection, Cache_Always };
+    enum CachePolicy {
+      Cache_No,
+      Cache_NoConnection,
+      Cache_Always
+    };
 
-    ResourceLDAPKIO( const KConfig* );
+    ResourceLDAPKIO();
+    explicit ResourceLDAPKIO( const KConfigGroup &group );
     virtual ~ResourceLDAPKIO();
     /**
      *  Call this after you used one of the set... methods
      */
     virtual void init();
 
-    virtual void writeConfig( KConfig* );
+    virtual void writeConfig( KConfigGroup &group );
 
     virtual bool doOpen();
     virtual void doClose();
 
     virtual Ticket *requestSaveTicket();
-    virtual void releaseSaveTicket( Ticket* );
+    virtual void releaseSaveTicket( Ticket *ticket );
 
     virtual bool readOnly() const { return Resource::readOnly(); }
     virtual void setReadOnly( bool value );
 
     virtual bool load();
     virtual bool asyncLoad();
-    virtual bool save( Ticket * );
-    virtual bool asyncSave( Ticket * );
+    virtual bool save( Ticket *ticket );
+    virtual bool asyncSave( Ticket *ticket );
 
-    virtual void removeAddressee( const Addressee& addr );
+    virtual void removeAddressee( const Addressee &addr );
 
     void setUser( const QString &user );
     QString user() const;
@@ -104,16 +107,16 @@ class KABC_LDAPKIO_EXPORT ResourceLDAPKIO : public Resource
     int RDNPrefix() const;
 
     void setIsTLS( bool value );
-    bool isTLS() const ;
+    bool isTLS() const;
 
     void setIsSSL( bool value );
     bool isSSL() const;
 
     void setIsSubTree( bool value );
-    bool isSubTree() const ;
+    bool isSubTree() const;
 
     void setIsSASL( bool value );
-    bool isSASL() const ;
+    bool isSASL() const;
 
     void setMech( const QString &mech );
     QString mech() const;
@@ -127,42 +130,21 @@ class KABC_LDAPKIO_EXPORT ResourceLDAPKIO : public Resource
     QString cacheDst() const;
 
 protected Q_SLOTS:
-    void entries( KIO::Job*, const KIO::UDSEntryList& );
-    void data( KIO::Job*, const QByteArray& );
-    void result( KJob* );
-    void listResult( KJob* );
-    void syncLoadSaveResult( KJob* );
-    void saveResult( KJob* );
-    void saveData( KIO::Job*, QByteArray& );
-    void loadCacheResult( KJob* );
+    void entries( KIO::Job *job, const KIO::UDSEntryList &list );
+    void data( KIO::Job *job, const QByteArray &data );
+    void result( KJob *job );
+    void listResult( KJob *job );
+    void syncLoadSaveResult( KJob *job );
+    void saveResult( KJob *job );
+    void saveData( KIO::Job *job, QByteArray &data );
+    void loadCacheResult( KJob *job );
 
 Q_SIGNALS:
     void leaveModality();
 
   private:
-    QString mUser;
-    QString mPassword;
-    QString mDn;
-    QString mHost;
-    QString mFilter;
-    int mPort;
-    bool mAnonymous;
-    QMap<QString, QString> mAttributes;
-
-    KUrl mLDAPUrl;
-    QString mErrorMsg;
-
-    KIO::Job *loadFromCache();
-    void createCache();
-    void activateCache();
-    void enter_loop();
-    QByteArray addEntry( const QString &attr, const QString &value, bool mod );
-    QString findUid( const QString &uid );
-    bool AddresseeToLDIF( QByteArray &ldif, const Addressee &addr,
-      const QString &olddn );
-
-    class ResourceLDAPKIOPrivate;
-    ResourceLDAPKIOPrivate *d;
+    class Private;
+    Private *const d;
 };
 
 }
