@@ -37,6 +37,8 @@ ResourceNetConfig::ResourceNetConfig( QWidget *parent )
     : ConfigWidget( parent ), mInEditMode( false )
 {
   QGridLayout *mainLayout = new QGridLayout( this );
+  mainLayout->setMargin( 0 );
+  mainLayout->setSpacing( KDialog::spacingHint() );
 
   QLabel *label = new QLabel( i18n( "Format:" ), this );
   mFormatBox = new KComboBox( this );
