@@ -39,7 +39,9 @@
 #include "todo.h"
 #include "journal.h"
 #include "filestorage.h"
+#include <QtCore/QDate>
 #include <QtCore/QHash>
+#include <QtCore/QMultiHash>
 #include <QtCore/QString>
 
 #include <kdebug.h>
@@ -61,13 +63,16 @@ class KCal::CalendarLocal::Private
     {
       mDeletedIncidences.setAutoDelete( true );
     }
-    QString mFileName;                 // filename where the calendar is stored
-    CalFormat *mFormat;                // calendar format
+    QString mFileName;                      // filename where calendar is stored
+    CalFormat *mFormat;                     // calendar format
 
-    QHash<QString, Event *> mEvents;    // hash on uids of all calendar events
-    QHash<QString, Todo *> mTodos;      // hash on uids of all calendar to-dos
-    QHash<QString, Journal *> mJournals;// hash on uids of all calendar journals
-    Incidence::List mDeletedIncidences; // list of all deleted incidences
+    QHash<QString, Event *> mEvents;        // hash on uids of all Events
+    QMultiHash<QString, Event *> mEventsForDate; // on start dates of all non-recurring Events
+    QHash<QString, Todo *> mTodos;          // hash on uids of all To-dos
+    QMultiHash<QString, Todo*>mTodosForDate;// on due dates for all Todos
+    QHash<QString, Journal *> mJournals;    // hash on uids of all Journals
+    QMultiHash<QString, Journal *>mJournalsForDate; // on dates of all Journals
+    Incidence::List mDeletedIncidences;     // list of all deleted Incidences
 
     void insertEvent( Event *event );
     void insertTodo( Todo *todo );
@@ -166,10 +171,14 @@ bool CalendarLocal::addEvent( Event *event )
 
 bool CalendarLocal::deleteEvent( Event *event )
 {
-  if ( d->mEvents.remove( event->uid() ) ) {
+  QString uid = event->uid();
+  if ( d->mEvents.remove( uid ) ) {
     setModified( true );
     notifyIncidenceDeleted( event );
     d->mDeletedIncidences.append( event );
+    if ( !event->recurs() ) {
+      d->mEventsForDate.remove( event->dtStart().date().toString(), event );
+    }
     return true;
   } else {
     kWarning() << "CalendarLocal::deleteEvent(): Event not found.";
@@ -179,11 +188,14 @@ bool CalendarLocal::deleteEvent( Event *event )
 
 void CalendarLocal::deleteAllEvents()
 {
-  foreach ( Event *e, d->mEvents ) {
-    notifyIncidenceDeleted( e );
+  QHashIterator<QString, Event *>i( d->mEvents );
+  while ( i.hasNext() ) {
+    i.next();
+    notifyIncidenceDeleted( i.value() );
   }
   qDeleteAll( d->mEvents );
   d->mEvents.clear();
+  d->mEventsForDate.clear();
 }
 
 Event *CalendarLocal::event( const QString &uid )
@@ -213,6 +225,10 @@ void CalendarLocal::Private::insertTodo( Todo *todo )
   QString uid = todo->uid();
   if ( mTodos.value( uid ) == 0 ) {
     mTodos.insert( uid, todo );
+    if ( todo->hasDueDate() ) {
+      mTodosForDate.insert( todo->dtDue().date().toString(), todo );
+    }
+
   } else {
 #ifndef NDEBUG
     // if we already have an to-do with this UID, it must be the same to-do,
@@ -232,6 +248,9 @@ bool CalendarLocal::deleteTodo( Todo *todo )
     setModified( true );
     notifyIncidenceDeleted( todo );
     d->mDeletedIncidences.append( todo );
+    if ( todo->hasDueDate() ) {
+      d->mTodosForDate.remove( todo->dtDue().date().toString(), todo );
+    }
     return true;
   } else {
     kWarning() << "CalendarLocal::deleteTodo(): Todo not found.";
@@ -241,11 +260,14 @@ bool CalendarLocal::deleteTodo( Todo *todo )
 
 void CalendarLocal::deleteAllTodos()
 {
-  foreach ( Todo *t, d->mTodos ) {
-    notifyIncidenceDeleted( t );
+  QHashIterator<QString, Todo *>i( d->mTodos );
+  while ( i.hasNext() ) {
+    i.next();
+    notifyIncidenceDeleted( i.value() );
   }
   qDeleteAll( d->mTodos );
   d->mTodos.clear();
+  d->mTodosForDate.clear();
 }
 
 Todo *CalendarLocal::todo( const QString &uid )
@@ -257,8 +279,10 @@ Todo::List CalendarLocal::rawTodos( TodoSortField sortField,
                                     SortDirection sortDirection )
 {
   Todo::List todoList;
-  foreach ( Todo *t, d->mTodos ) {
-    todoList.append( t );
+  QHashIterator<QString, Todo *>i( d->mTodos );
+  while ( i.hasNext() ) {
+    i.next();
+    todoList.append( i.value() );
   }
   return sortTodos( &todoList, sortField, sortDirection );
 }
@@ -266,10 +290,14 @@ Todo::List CalendarLocal::rawTodos( TodoSortField sortField,
 Todo::List CalendarLocal::rawTodosForDate( const QDate &date )
 {
   Todo::List todoList;
-  foreach ( Todo *t, d->mTodos ) {
-    if ( t->hasDueDate() && t->dtDue().date() == date ) {
-      todoList.append( t );
-    }
+  Todo *t;
+
+  QString dateStr = date.toString();
+  QMultiHash<QString, Todo *>::iterator it = d->mTodosForDate.find( dateStr );
+  while ( it != d->mTodosForDate.end() && it.key() == dateStr ) {
+    t = it.value();
+    todoList.append( t );
+    ++it;
   }
   return todoList;
 }
@@ -281,22 +309,30 @@ Alarm::List CalendarLocal::alarmsTo( const KDateTime &to )
 
 Alarm::List CalendarLocal::alarms( const KDateTime &from, const KDateTime &to )
 {
-  Alarm::List alarms;
-  foreach ( Event *e, d->mEvents ) {
+  Alarm::List alarmList;
+  QHashIterator<QString, Event *>ie( d->mEvents );
+  Event *e;
+  while ( ie.hasNext() ) {
+    ie.next();
+    e = ie.value();
     if ( e->recurs() ) {
-      appendRecurringAlarms( alarms, e, from, to );
+      appendRecurringAlarms( alarmList, e, from, to );
     } else {
-      appendAlarms( alarms, e, from, to );
+      appendAlarms( alarmList, e, from, to );
     }
   }
 
-  foreach ( Todo *t, d->mTodos ) {
+  QHashIterator<QString, Todo *>it( d->mTodos );
+  Todo *t;
+  while ( it.hasNext() ) {
+    it.next();
+    t = it.value();
     if (! t->isCompleted() ) {
-      appendAlarms( alarms, t, from, to );
+      appendAlarms( alarmList, t, from, to );
     }
   }
 
-  return alarms;
+  return alarmList;
 }
 
 //@cond PRIVATE
@@ -305,6 +341,9 @@ void CalendarLocal::Private::insertEvent( Event *event )
   QString uid = event->uid();
   if ( mEvents.value( uid ) == 0 ) {
     mEvents.insert( uid, event );
+    if ( !event->recurs() ) {
+      mEventsForDate.insert( event->dtStart().date().toString(), event );
+    }
   } else {
 #ifdef NDEBUG
     // if we already have an event with this UID, it must be the same event,
@@ -329,42 +368,52 @@ void CalendarLocal::incidenceUpdated( IncidenceBase *incidence )
   setModified( true );
 }
 
-Event::List CalendarLocal::rawEventsForDate( const QDate &qd,
+Event::List CalendarLocal::rawEventsForDate( const QDate &date,
                                              const KDateTime::Spec &timespec,
                                              EventSortField sortField,
                                              SortDirection sortDirection )
 {
   Event::List eventList;
+  Event *ev;
+
+  // Find the hash for the specified date
+  QString dateStr = date.toString();
+  QMultiHash<QString, Event *>::iterator it = d->mEventsForDate.find( dateStr );
+  // Iterate over all non-recurring events that start on this date
   KDateTime::Spec ts = timespec.isValid() ? timespec : timeSpec();
+  KDateTime kdt( date, ts );
+  while ( it != d->mEventsForDate.end() && it.key() == dateStr ) {
+    ev = it.value();
+    KDateTime end( ev->dtEnd().toTimeSpec( ev->dtStart() ) );
+    if ( ev->allDay() ) {
+      end.setDateOnly( true );
+    } else {
+      end = end.addSecs(-1);
+    }
+    if ( end >= kdt ) {
+      eventList.append( ev );
+    }
+    ++it;
+  }
 
-  foreach ( Event *event, d->mEvents ) {
-
-    if ( event->recurs() ) {
-      if ( event->isMultiDay() ) {
-        int extraDays = event->dtStart().date().daysTo( event->dtEnd().date() );
+  // Iterate over all events. Look for recurring events that occur on this date
+  QHashIterator<QString, Event *>i( d->mEvents );
+  while ( i.hasNext() ) {
+    i.next();
+    ev = i.value();
+    if ( ev->recurs() ) {
+      if ( ev->isMultiDay() ) {
+        int extraDays = ev->dtStart().date().daysTo( ev->dtEnd().date() );
         int i;
         for ( i = 0; i <= extraDays; i++ ) {
-          if ( event->recursOn( qd.addDays( -i ), ts ) ) {
-            eventList.append( event );
+          if ( ev->recursOn( date.addDays( -i ), ts ) ) {
+            eventList.append( ev );
             break;
           }
         }
       } else {
-        if ( event->recursOn( qd, ts ) ) {
-          eventList.append( event );
-        }
-      }
-    } else {
-      KDateTime kdt( qd, ts );
-      if ( event->dtStart() <= kdt ) {
-        KDateTime end( event->dtEnd().toTimeSpec( event->dtStart() ) );
-        if ( event->allDay() ) {
-          end.setDateOnly( true );
-        } else {
-          end = end.addSecs(-1);
-        }
-        if ( end >= kdt ) {
-          eventList.append( event );
+        if ( ev->recursOn( date, ts ) ) {
+          eventList.append( ev );
         }
       }
     }
@@ -383,7 +432,11 @@ Event::List CalendarLocal::rawEvents( const QDate &start, const QDate &end,
   KDateTime yesterStart = st.addDays( -1 );
 
   // Get non-recurring events
-  foreach ( Event *event, d->mEvents ) {
+  QHashIterator<QString, Event *>i( d->mEvents );
+  Event *event;
+  while ( i.hasNext() ) {
+    i.next();
+    event = i.value();
     KDateTime rStart = event->dtStart();
     if ( nd < rStart ) {
       continue;
@@ -438,8 +491,10 @@ Event::List CalendarLocal::rawEvents( EventSortField sortField,
                                       SortDirection sortDirection )
 {
   Event::List eventList;
-  foreach ( Event *e, d->mEvents ) {
-    eventList.append( e );
+  QHashIterator<QString, Event *>i( d->mEvents );
+  while ( i.hasNext() ) {
+    i.next();
+    eventList.append( i.value() );
   }
   return sortEvents( &eventList, sortField, sortDirection );
 }
@@ -463,6 +518,7 @@ void CalendarLocal::Private::insertJournal( Journal *journal )
   QString uid = journal->uid();
   if ( mJournals.value( uid ) == 0 ) {
     mJournals.insert( uid, journal );
+    mJournalsForDate.insert( journal->dtStart().date().toString(), journal );
   } else {
 #ifndef NDEBUG
     // if we already have an journal with this UID, it must be the same journal,
@@ -479,6 +535,7 @@ bool CalendarLocal::deleteJournal( Journal *journal )
     setModified( true );
     notifyIncidenceDeleted( journal );
     d->mDeletedIncidences.append( journal );
+    d->mJournalsForDate.remove( journal->dtStart().date().toString(), journal );
     return true;
   } else {
     kWarning() << "CalendarLocal::deleteJournal(): Journal not found.";
@@ -488,11 +545,14 @@ bool CalendarLocal::deleteJournal( Journal *journal )
 
 void CalendarLocal::deleteAllJournals()
 {
-  foreach ( Journal *j, d->mJournals ) {
-    notifyIncidenceDeleted( j );
+  QHashIterator<QString, Journal *>i( d->mJournals );
+  while ( i.hasNext() ) {
+    i.next();
+    notifyIncidenceDeleted( i.value() );
   }
   qDeleteAll( d->mJournals );
   d->mJournals.clear();
+  d->mJournalsForDate.clear();
 }
 
 Journal *CalendarLocal::journal( const QString &uid )
@@ -504,8 +564,10 @@ Journal::List CalendarLocal::rawJournals( JournalSortField sortField,
                                           SortDirection sortDirection )
 {
   Journal::List journalList;
-  foreach ( Journal *j, d->mJournals ) {
-    journalList.append( j );
+  QHashIterator<QString, Journal *>i( d->mJournals );
+  while ( i.hasNext() ) {
+    i.next();
+    journalList.append( i.value() );
   }
   return sortJournals( &journalList, sortField, sortDirection );
 }
@@ -513,10 +575,15 @@ Journal::List CalendarLocal::rawJournals( JournalSortField sortField,
 Journal::List CalendarLocal::rawJournalsForDate( const QDate &date )
 {
   Journal::List journalList;
-  foreach ( Journal *j, d->mJournals ) {
-    if ( j->dtStart().date() == date ) {
-      journalList.append( j );
-    }
+  Journal *j;
+
+  QString dateStr = date.toString();
+  QMultiHash<QString, Journal *>::iterator it = d->mJournalsForDate.find( dateStr );
+
+  while ( it != d->mJournalsForDate.end() && it.key() == dateStr ) {
+    j = it.value();
+    journalList.append( j );
+    ++it;
   }
   return journalList;
 }
