@@ -1,64 +1,189 @@
 /*
-    This file is part of the kcal library.
+  This file is part of the kcal library.
 
-    Copyright (c) 2003 Cornelius Schumacher <schumacher@kde.org>
-    Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  Copyright (c) 2003 Cornelius Schumacher <schumacher@kde.org>
+  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
+  This library is free software; you can redistribute it and/or
+  modify it under the terms of the GNU Library General Public
+  License as published by the Free Software Foundation; either
+  version 2 of the License, or (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  Library General Public License for more details.
 
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 /**
   @file
   This file is part of the API for handling calendar data and
   defines the CalendarResources class.
 
-  @author Cornelius Schumacher
-  @author Reinhold Kainhofer
-*/
-#include <stdlib.h>
+   @brief
+   This class provides a Calendar which is composed of other Calendars
+   known as "Resources".
 
-#include <QString>
-#include <QList>
+  @author Cornelius Schumacher \<schumacher@kde.org\>
+  @author Reinhold Kainhofer \<reinhold@kainhofer.com\>
+*/
+
+#include "calendarresources.moc"
+#include "incidence.h"
+#include "journal.h"
+#include "resourcecalendar.h"
+
+#include "kresources/manager.h"
+#include "kresources/selectdialog.h"
+#include "kabc/lock.h"
 
 #include <kdebug.h>
 #include <kdatetime.h>
 #include <kstandarddirs.h>
 #include <klocale.h>
 
-#include "kresources/manager.h"
-#include "kresources/selectdialog.h"
-#include "kabc/lock.h"
+#include <QtCore/QString>
+#include <QtCore/QList>
 
-#include "incidence.h"
-#include "journal.h"
-#include "resourcecalendar.h"
-#include "calendarresources.h"
+#include <stdlib.h>
 
 using namespace KCal;
 
-ResourceCalendar
-*CalendarResources::StandardDestinationPolicy::destination( Incidence *i )
+/**
+  Private classes that helps to provide binary compatibility between releases.
+  @internal
+*/
+//@cond PRIVATE
+class KCal::CalendarResources::Private
 {
-  Q_UNUSED( i );
+  public:
+    Private( const QString &family )
+      : mManager( new CalendarResourceManager( family ) ),
+        mStandardPolicy( new StandardDestinationPolicy( mManager ) ),
+        mDestinationPolicy( mStandardPolicy ),
+        mAskPolicy( new AskDestinationPolicy( mManager ) )
+    {}
+    ~Private()
+    {
+      delete mManager;
+      delete mStandardPolicy;
+      delete mAskPolicy;
+    }
+    bool mOpen;  //flag that indicates if the resources are "open"
+
+    KRES::Manager<ResourceCalendar>* mManager;
+    QMap <Incidence*, ResourceCalendar*> mResourceMap;
+
+    StandardDestinationPolicy *mStandardPolicy;
+    DestinationPolicy *mDestinationPolicy;
+    AskDestinationPolicy *mAskPolicy;
+
+    QMap<ResourceCalendar *, Ticket *> mTickets;
+    QMap<ResourceCalendar *, int> mChangeCounts;
+
+    template< class IncidenceList >
+    void appendIncidences( IncidenceList &result, const IncidenceList &extra,
+                           ResourceCalendar * );
+};
+
+class KCal::CalendarResources::DestinationPolicy::Private
+{
+  public:
+    Private( CalendarResourceManager *manager, QWidget *parent )
+      : mManager( manager ),
+        mParent( parent )
+    {}
+    CalendarResourceManager *mManager;
+    QWidget *mParent;
+};
+
+class KCal::CalendarResources::StandardDestinationPolicy::Private
+{
+  public:
+    Private()
+    {}
+};
+
+class KCal::CalendarResources::AskDestinationPolicy::Private
+{
+  public:
+    Private()
+    {}
+};
+
+class KCal::CalendarResources::Ticket::Private
+{
+  public:
+    Private( ResourceCalendar *resource )
+      : mResource( resource )
+    {}
+    ResourceCalendar *mResource;
+};
+//@endcond
+
+CalendarResources::DestinationPolicy::DestinationPolicy(
+  CalendarResourceManager *manager, QWidget *parent )
+  : d( new KCal::CalendarResources::DestinationPolicy::Private( manager, parent ) )
+{
+}
+
+CalendarResources::DestinationPolicy::~DestinationPolicy()
+{
+  delete d;
+}
+
+QWidget *CalendarResources::DestinationPolicy::parent()
+{
+  return d->mParent;
+}
+
+void CalendarResources::DestinationPolicy::setParent( QWidget *parent )
+{
+  d->mParent = parent;
+}
+
+CalendarResourceManager *CalendarResources::DestinationPolicy::resourceManager()
+{
+  return d->mManager;
+}
+
+CalendarResources::StandardDestinationPolicy::StandardDestinationPolicy(
+  CalendarResourceManager *manager, QWidget *parent )
+  : DestinationPolicy( manager, parent ),
+    d( new KCal::CalendarResources::StandardDestinationPolicy::Private )
+{
+}
+
+CalendarResources::StandardDestinationPolicy::~StandardDestinationPolicy()
+{
+  delete d;
+}
+
+ResourceCalendar *CalendarResources::StandardDestinationPolicy::destination( Incidence *incidence )
+{
+  Q_UNUSED( incidence );
   return resourceManager()->standardResource();
 }
 
-ResourceCalendar
-*CalendarResources::AskDestinationPolicy::destination( Incidence *i )
+CalendarResources::AskDestinationPolicy::AskDestinationPolicy(
+  CalendarResourceManager *manager, QWidget *parent )
+  : DestinationPolicy( manager, parent ),
+    d( new KCal::CalendarResources::AskDestinationPolicy::Private )
 {
-  Q_UNUSED( i );
+}
+
+CalendarResources::AskDestinationPolicy::~AskDestinationPolicy()
+{
+  delete d;
+}
+
+ResourceCalendar *CalendarResources::AskDestinationPolicy::destination( Incidence *incidence )
+{
+  Q_UNUSED( incidence );
   QList<KRES::Resource*> list;
 
   CalendarResourceManager::ActiveIterator it;
@@ -81,60 +206,46 @@ ResourceCalendar
 
 CalendarResources::CalendarResources( const KDateTime::Spec &timeSpec,
                                       const QString &family )
-  : Calendar( timeSpec )
+  : Calendar( timeSpec ),
+    d( new KCal::CalendarResources::Private( family ) )
 {
-  init( family );
+  d->mManager->addObserver( this );
 }
 
 CalendarResources::CalendarResources( const QString &timeZoneId,
                                       const QString &family )
-  : Calendar( timeZoneId )
+  : Calendar( timeZoneId ),
+    d( new KCal::CalendarResources::Private( family ) )
 {
-  init( family );
-}
-
-void CalendarResources::init( const QString &family )
-{
-  kDebug(5800) << "CalendarResources::init( " << family << " )" << endl;
-
-  mManager = new CalendarResourceManager( family );
-  mManager->addObserver( this );
-
-  mStandardPolicy = new StandardDestinationPolicy( mManager );
-  mAskPolicy = new AskDestinationPolicy( mManager );
-  mDestinationPolicy = mStandardPolicy;
+  d->mManager->addObserver( this );
 }
 
 CalendarResources::~CalendarResources()
 {
   close();
-  delete mManager;
-  delete mStandardPolicy;
-  delete mAskPolicy;
+  delete d;
 }
 
 void CalendarResources::readConfig( KConfig *config )
 {
-  mManager->readConfig( config );
+  d->mManager->readConfig( config );
 
   CalendarResourceManager::Iterator it;
-  for ( it = mManager->begin(); it != mManager->end(); ++it ) {
+  for ( it = d->mManager->begin(); it != d->mManager->end(); ++it ) {
     connectResource( *it );
   }
 }
 
 void CalendarResources::load()
 {
-  kDebug(5800) << "CalendarResources::load()" << endl;
-
-  if ( !mManager->standardResource() ) {
-    kDebug(5800) << "Warning! No standard resource yet." << endl;
+  if ( !d->mManager->standardResource() ) {
+    kDebug(5800) << "Warning! No standard resource yet.";
   }
 
   // set the timezone for all resources. Otherwise we'll have those terrible tz
   // troubles ;-((
   CalendarResourceManager::Iterator i1;
-  for ( i1 = mManager->begin(); i1 != mManager->end(); ++i1 ) {
+  for ( i1 = d->mManager->begin(); i1 != d->mManager->end(); ++i1 ) {
     (*i1)->setTimeSpec( timeSpec() );
   }
 
@@ -142,7 +253,7 @@ void CalendarResources::load()
 
   // Open all active resources
   CalendarResourceManager::ActiveIterator it;
-  for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
     if ( !(*it)->load() ) {
       failed.append( *it );
     }
@@ -160,7 +271,7 @@ void CalendarResources::load()
     emit signalResourceModified( *it2 );
   }
 
-  mOpen = true;
+  d->mOpen = true;
 }
 
 bool CalendarResources::reload()
@@ -171,58 +282,63 @@ bool CalendarResources::reload()
   return true;
 }
 
+CalendarResourceManager *CalendarResources::resourceManager() const
+{
+  return d->mManager;
+}
+
 void CalendarResources::setStandardDestinationPolicy()
 {
-  mDestinationPolicy = mStandardPolicy;
+  d->mDestinationPolicy = d->mStandardPolicy;
 }
 
 void CalendarResources::setAskDestinationPolicy()
 {
-  mDestinationPolicy = mAskPolicy;
+  d->mDestinationPolicy = d->mAskPolicy;
 }
 
 QWidget *CalendarResources::dialogParentWidget()
 {
-  return mDestinationPolicy->parent();
-}
-void CalendarResources::setDialogParentWidget( QWidget *parent )
-{
-  mDestinationPolicy->setParent( parent );
+  return d->mDestinationPolicy->parent();
 }
 
+void CalendarResources::setDialogParentWidget( QWidget *parent )
+{
+  d->mDestinationPolicy->setParent( parent );
+}
 
 void CalendarResources::close()
 {
-  kDebug(5800) << "CalendarResources::close" << endl;
-
-  if ( mOpen ) {
+  if ( d->mOpen ) {
     CalendarResourceManager::ActiveIterator it;
-    for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
+    for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
       (*it)->close();
     }
 
     setModified( false );
-    mOpen = false;
+    d->mOpen = false;
   }
 }
 
-void CalendarResources::save()
+bool CalendarResources::save()
 {
-  kDebug(5800) << "CalendarResources::save()" << endl;
-
-  if ( mOpen && isModified() ) {
+  bool status = true;
+  if ( d->mOpen && isModified() ) {
+    status = false;
     CalendarResourceManager::ActiveIterator it;
-    for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
-      (*it)->save();
+    for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
+      status = (*it)->save() || status;
     }
     setModified( false );
   }
+
+  return status;
 }
 
 bool CalendarResources::isSaving()
 {
   CalendarResourceManager::ActiveIterator it;
-  for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
     if ( (*it)->isSaving() ) {
       return true;
     }
@@ -236,20 +352,20 @@ bool CalendarResources::addIncidence( Incidence *incidence,
   // FIXME: Use proper locking via begin/endChange!
   bool validRes = false;
   CalendarResourceManager::ActiveIterator it;
-  for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
     if ( (*it) == resource ) {
       validRes = true;
     }
   }
 
   ResourceCalendar *oldResource = 0;
-  if ( mResourceMap.contains( incidence ) ) {
-    oldResource = mResourceMap[incidence];
+  if ( d->mResourceMap.contains( incidence ) ) {
+    oldResource = d->mResourceMap[incidence];
   }
-  mResourceMap[incidence] = resource;
+  d->mResourceMap[incidence] = resource;
   if ( validRes && beginChange( incidence ) &&
        resource->addIncidence( incidence ) ) {
-//    mResourceMap[incidence] = resource;
+//    d->mResourceMap[incidence] = resource;
     incidence->registerObserver( this );
     notifyIncidenceAdded( incidence );
     setModified( true );
@@ -257,9 +373,9 @@ bool CalendarResources::addIncidence( Incidence *incidence,
     return true;
   } else {
     if ( oldResource ) {
-      mResourceMap[incidence] = oldResource;
+      d->mResourceMap[incidence] = oldResource;
     } else {
-      mResourceMap.remove( incidence );
+      d->mResourceMap.remove( incidence );
     }
   }
 
@@ -268,26 +384,24 @@ bool CalendarResources::addIncidence( Incidence *incidence,
 
 bool CalendarResources::addIncidence( Incidence *incidence )
 {
-  kDebug(5800) << "CalendarResources::addIncidence" << this << endl;
-
-  ResourceCalendar *resource = mDestinationPolicy->destination( incidence );
+  ResourceCalendar *resource = d->mDestinationPolicy->destination( incidence );
 
   if ( resource ) {
-    mResourceMap[ incidence ] = resource;
+    d->mResourceMap[ incidence ] = resource;
 
     if ( beginChange( incidence ) && resource->addIncidence( incidence ) ) {
       incidence->registerObserver( this );
       notifyIncidenceAdded( incidence );
 
-      mResourceMap[ incidence ] = resource;
+      d->mResourceMap[ incidence ] = resource;
       setModified( true );
       endChange( incidence );
       return true;
     } else {
-      mResourceMap.remove( incidence );
+      d->mResourceMap.remove( incidence );
     }
   } else {
-    kDebug(5800) << "CalendarResources::addIncidence(): no resource" << endl;
+    kDebug(5800) << "CalendarResources::addIncidence(): no resource";
   }
 
   return false;
@@ -295,7 +409,6 @@ bool CalendarResources::addIncidence( Incidence *incidence )
 
 bool CalendarResources::addEvent( Event *event )
 {
-  kDebug(5800) << "CalendarResources::addEvent" << endl;
   return addIncidence( event );
 }
 
@@ -306,18 +419,16 @@ bool CalendarResources::addEvent( Event *Event, ResourceCalendar *resource )
 
 bool CalendarResources::deleteEvent( Event *event )
 {
-  kDebug(5800) << "CalendarResources::deleteEvent" << endl;
-
   bool status;
-  if ( mResourceMap.find( event ) != mResourceMap.end() ) {
-    status = mResourceMap[event]->deleteEvent( event );
+  if ( d->mResourceMap.find( event ) != d->mResourceMap.end() ) {
+    status = d->mResourceMap[event]->deleteEvent( event );
     if ( status ) {
-      mResourceMap.remove( event );
+      d->mResourceMap.remove( event );
     }
   } else {
     status = false;
     CalendarResourceManager::ActiveIterator it;
-    for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
+    for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
       status = (*it)->deleteEvent( event ) || status;
     }
   }
@@ -326,13 +437,21 @@ bool CalendarResources::deleteEvent( Event *event )
   return status;
 }
 
+void CalendarResources::deleteAllEvents()
+{
+  CalendarResourceManager::ActiveIterator it;
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
+    (*it)->deleteAllEvents();
+  }
+}
+
 Event *CalendarResources::event( const QString &uid )
 {
   CalendarResourceManager::ActiveIterator it;
-  for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
-    Event* event = (*it)->event( uid );
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
+    Event *event = (*it)->event( uid );
     if ( event ) {
-      mResourceMap[event] = *it;
+      d->mResourceMap[event] = *it;
       return event;
     }
   }
@@ -343,7 +462,6 @@ Event *CalendarResources::event( const QString &uid )
 
 bool CalendarResources::addTodo( Todo *todo )
 {
-  kDebug(5800) << "CalendarResources::addTodo" << endl;
   return addIncidence( todo );
 }
 
@@ -354,18 +472,16 @@ bool CalendarResources::addTodo( Todo *todo, ResourceCalendar *resource )
 
 bool CalendarResources::deleteTodo( Todo *todo )
 {
-  kDebug(5800) << "CalendarResources::deleteTodo" << endl;
-
   bool status;
-  if ( mResourceMap.find( todo ) != mResourceMap.end() ) {
-    status = mResourceMap[todo]->deleteTodo( todo );
+  if ( d->mResourceMap.find( todo ) != d->mResourceMap.end() ) {
+    status = d->mResourceMap[todo]->deleteTodo( todo );
     if ( status ) {
-      mResourceMap.remove( todo );
+      d->mResourceMap.remove( todo );
     }
   } else {
     CalendarResourceManager::ActiveIterator it;
     status = false;
-    for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
+    for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
       status = (*it)->deleteTodo( todo ) || status;
     }
   }
@@ -374,28 +490,34 @@ bool CalendarResources::deleteTodo( Todo *todo )
   return status;
 }
 
+void CalendarResources::deleteAllTodos()
+{
+  CalendarResourceManager::ActiveIterator it;
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
+    (*it)->deleteAllTodos();
+  }
+}
+
 Todo::List CalendarResources::rawTodos( TodoSortField sortField,
                                         SortDirection sortDirection )
 {
   Todo::List result;
 
   CalendarResourceManager::ActiveIterator it;
-  for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
-    appendIncidences<Todo::List>( result,
-                                  (*it)->rawTodos( TodoSortUnsorted ), *it );
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
+    d->appendIncidences<Todo::List>( result,
+                                     (*it)->rawTodos( TodoSortUnsorted ), *it );
   }
   return sortTodos( &result, sortField, sortDirection );
 }
 
 Todo *CalendarResources::todo( const QString &uid )
 {
-  kDebug(5800) << "CalendarResources::todo(uid)" << endl;
-
   CalendarResourceManager::ActiveIterator it;
-  for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
     Todo *todo = (*it)->todo( uid );
     if ( todo ) {
-      mResourceMap[todo] = *it;
+      d->mResourceMap[todo] = *it;
       return todo;
     }
   }
@@ -409,19 +531,18 @@ Todo::List CalendarResources::rawTodosForDate( const QDate &date )
   Todo::List result;
 
   CalendarResourceManager::ActiveIterator it;
-  for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
-    appendIncidences<Todo::List>( result, (*it)->rawTodosForDate( date ), *it );
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
+    d->appendIncidences<Todo::List>( result,
+                                     (*it)->rawTodosForDate( date ), *it );
   }
   return result;
 }
 
 Alarm::List CalendarResources::alarmsTo( const KDateTime &to )
 {
-  kDebug(5800) << "CalendarResources::alarmsTo" << endl;
-
   Alarm::List result;
   CalendarResourceManager::ActiveIterator it;
-  for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
     result += (*it)->alarmsTo( to );
   }
   return result;
@@ -432,7 +553,7 @@ Alarm::List CalendarResources::alarms( const KDateTime &from,
 {
   Alarm::List result;
   CalendarResourceManager::ActiveIterator it;
-  for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
     result += (*it)->alarms( from, to );
   }
   return result;
@@ -441,42 +562,39 @@ Alarm::List CalendarResources::alarms( const KDateTime &from,
 /****************************** PROTECTED METHODS ****************************/
 
 Event::List CalendarResources::rawEventsForDate( const QDate &date,
+                                                 const KDateTime::Spec &timespec,
                                                  EventSortField sortField,
                                                  SortDirection sortDirection )
 {
   Event::List result;
   CalendarResourceManager::ActiveIterator it;
-  for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
-    appendIncidences<Event::List>( result,
-                                   (*it)->rawEventsForDate( date ), *it );
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
+    d->appendIncidences<Event::List>( result,
+                                      (*it)->rawEventsForDate( date, timespec ), *it );
   }
   return sortEvents( &result, sortField, sortDirection );
 }
 
 Event::List CalendarResources::rawEvents( const QDate &start, const QDate &end,
-                                          bool inclusive )
+                                          const KDateTime::Spec &timespec, bool inclusive )
 {
-  kDebug(5800) << "CalendarResources::rawEvents(start,end,inclusive)" << endl;
-
   Event::List result;
   CalendarResourceManager::ActiveIterator it;
-  for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
-    appendIncidences<Event::List>( result,
-                                   (*it)->rawEvents( start, end, inclusive ), *it );
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
+    d->appendIncidences<Event::List>( result,
+                                      (*it)->rawEvents( start, end, timespec, inclusive ), *it );
   }
   return result;
 }
 
-Event::List CalendarResources::rawEventsForDate( const KDateTime &qdt )
+Event::List CalendarResources::rawEventsForDate( const KDateTime &kdt )
 {
-  kDebug(5800) << "CalendarResources::rawEventsForDate(qdt)" << endl;
-
   // @TODO: Remove the code duplication by the resourcemap iteration block.
   Event::List result;
   CalendarResourceManager::ActiveIterator it;
-  for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
-    appendIncidences<Event::List>( result,
-                                   (*it)->rawEventsForDate( qdt ), *it );
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
+    d->appendIncidences<Event::List>( result,
+                                      (*it)->rawEventsForDate( kdt ), *it );
   }
   return result;
 }
@@ -484,37 +602,32 @@ Event::List CalendarResources::rawEventsForDate( const KDateTime &qdt )
 Event::List CalendarResources::rawEvents( EventSortField sortField,
                                           SortDirection sortDirection )
 {
-  kDebug(5800) << "CalendarResources::rawEvents()" << endl;
-
   Event::List result;
   CalendarResourceManager::ActiveIterator it;
-  for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
-    appendIncidences<Event::List>( result,
-                                   (*it)->rawEvents( EventSortUnsorted ), *it );
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
+    d->appendIncidences<Event::List>( result,
+                                      (*it)->rawEvents( EventSortUnsorted ), *it );
   }
   return sortEvents( &result, sortField, sortDirection );
 }
 
 bool CalendarResources::addJournal( Journal *journal )
 {
-  kDebug(5800) << "CalendarResources::addJournal" << endl;
   return addIncidence( journal );
 }
 
 bool CalendarResources::deleteJournal( Journal *journal )
 {
-  kDebug(5800) << "CalendarResources::deleteJournal" << endl;
-
   bool status;
-  if ( mResourceMap.find( journal ) != mResourceMap.end() ) {
-    status = mResourceMap[journal]->deleteJournal( journal );
+  if ( d->mResourceMap.find( journal ) != d->mResourceMap.end() ) {
+    status = d->mResourceMap[journal]->deleteJournal( journal );
     if ( status ) {
-      mResourceMap.remove( journal );
+      d->mResourceMap.remove( journal );
     }
   } else {
     CalendarResourceManager::ActiveIterator it;
     status = false;
-    for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
+    for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
       status = (*it)->deleteJournal( journal ) || status;
     }
   }
@@ -523,6 +636,14 @@ bool CalendarResources::deleteJournal( Journal *journal )
   return status;
 }
 
+void CalendarResources::deleteAllJournals()
+{
+  CalendarResourceManager::ActiveIterator it;
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
+    (*it)->deleteAllJournals();
+  }
+}
+
 bool CalendarResources::addJournal( Journal *journal,
                                     ResourceCalendar *resource )
 {
@@ -531,13 +652,11 @@ bool CalendarResources::addJournal( Journal *journal,
 
 Journal *CalendarResources::journal( const QString &uid )
 {
-  kDebug(5800) << "CalendarResources::journal(uid)" << endl;
-
   CalendarResourceManager::ActiveIterator it;
-  for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
-    Journal* journal = (*it)->journal( uid );
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
+    Journal *journal = (*it)->journal( uid );
     if ( journal ) {
-      mResourceMap[journal] = *it;
+      d->mResourceMap[journal] = *it;
       return journal;
     }
   }
@@ -549,13 +668,11 @@ Journal *CalendarResources::journal( const QString &uid )
 Journal::List CalendarResources::rawJournals( JournalSortField sortField,
                                               SortDirection sortDirection )
 {
-  kDebug(5800) << "CalendarResources::rawJournals()" << endl;
-
   Journal::List result;
   CalendarResourceManager::ActiveIterator it;
-  for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
-    appendIncidences<Journal::List>( result,
-                                     (*it)->rawJournals( JournalSortUnsorted ), *it );
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
+    d->appendIncidences<Journal::List>( result,
+                                        (*it)->rawJournals( JournalSortUnsorted ), *it );
   }
   return sortJournals( &result, sortField, sortDirection );
 }
@@ -566,17 +683,18 @@ Journal::List CalendarResources::rawJournalsForDate( const QDate &date )
   Journal::List result;
 
   CalendarResourceManager::ActiveIterator it;
-  for ( it = mManager->activeBegin(); it != mManager->activeEnd(); ++it ) {
-    appendIncidences<Journal::List>( result,
-                                     (*it)->rawJournalsForDate( date ), *it );
+  for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
+    d->appendIncidences<Journal::List>( result,
+                                        (*it)->rawJournalsForDate( date ), *it );
   }
   return result;
 }
 
+//@cond PRIVATE
 template< class IncidenceList >
-void CalendarResources::appendIncidences( IncidenceList &result,
-                                          const IncidenceList &extra,
-                                          ResourceCalendar *resource )
+void CalendarResources::Private::appendIncidences( IncidenceList &result,
+                                                   const IncidenceList &extra,
+                                                   ResourceCalendar *resource )
 {
   result += extra;
   for ( typename IncidenceList::ConstIterator it = extra.begin();
@@ -585,6 +703,7 @@ void CalendarResources::appendIncidences( IncidenceList &result,
     mResourceMap[ *it ] = resource;
   }
 }
+//@endcond
 
 void CalendarResources::connectResource( ResourceCalendar *resource )
 {
@@ -603,16 +722,14 @@ void CalendarResources::connectResource( ResourceCalendar *resource )
 
 ResourceCalendar *CalendarResources::resource( Incidence *incidence )
 {
-  if ( mResourceMap.find( incidence ) != mResourceMap.end() ) {
-    return mResourceMap[ incidence ];
+  if ( d->mResourceMap.find( incidence ) != d->mResourceMap.end() ) {
+    return d->mResourceMap[ incidence ];
   }
   return 0;
 }
 
 void CalendarResources::resourceAdded( ResourceCalendar *resource )
 {
-  kDebug(5800) << "Resource added: " << resource->resourceName() << endl;
-
   if ( !resource->isActive() ) {
     return;
   }
@@ -628,15 +745,11 @@ void CalendarResources::resourceAdded( ResourceCalendar *resource )
 
 void CalendarResources::resourceModified( ResourceCalendar *resource )
 {
-  kDebug(5800) << "Resource modified: " << resource->resourceName() << endl;
-
   emit signalResourceModified( resource );
 }
 
 void CalendarResources::resourceDeleted( ResourceCalendar *resource )
 {
-  kDebug(5800) << "Resource deleted: " << resource->resourceName() << endl;
-
   emit signalResourceDeleted( resource );
 }
 
@@ -645,16 +758,23 @@ void CalendarResources::doSetTimeSpec( const KDateTime::Spec &timeSpec )
   // set the timezone for all resources. Otherwise we'll have those terrible
   // tz troubles ;-((
   CalendarResourceManager::Iterator i1;
-  for ( i1 = mManager->begin(); i1 != mManager->end(); ++i1 ) {
+  for ( i1 = d->mManager->begin(); i1 != d->mManager->end(); ++i1 ) {
     (*i1)->setTimeSpec( timeSpec );
   }
 }
 
-CalendarResources::Ticket
-*CalendarResources::requestSaveTicket( ResourceCalendar *resource )
+CalendarResources::Ticket::Ticket( ResourceCalendar *resource )
+  : d( new KCal::CalendarResources::Ticket::Private( resource ) )
 {
-  kDebug(5800) << "CalendarResources::requestSaveTicket()" << endl;
+}
 
+CalendarResources::Ticket::~Ticket()
+{
+  delete d;
+}
+
+CalendarResources::Ticket *CalendarResources::requestSaveTicket( ResourceCalendar *resource )
+{
   KABC::Lock *lock = resource->lock();
   if ( !lock ) {
     return 0;
@@ -666,17 +786,18 @@ CalendarResources::Ticket
   }
 }
 
+ResourceCalendar *CalendarResources::Ticket::resource() const
+{
+  return d->mResource;
+}
+
 bool CalendarResources::save( Ticket *ticket, Incidence *incidence )
 {
-  kDebug(5800) << "CalendarResources::save( Ticket *)" << endl;
-
   if ( !ticket || !ticket->resource() ) {
     return false;
   }
 
-  kDebug(5800) << "tick " << ticket->resource()->resourceName() << endl;
-
-    // @TODO: Check if the resource was changed at all. If not, don't save.
+  // @TODO: Check if the resource was changed at all. If not, don't save.
   if ( ticket->resource()->save( incidence ) ) {
     releaseSaveTicket( ticket );
     return true;
@@ -693,28 +814,25 @@ void CalendarResources::releaseSaveTicket( Ticket *ticket )
 
 bool CalendarResources::beginChange( Incidence *incidence )
 {
-  kDebug(5800) << "CalendarResources::beginChange()" << endl;
-
   ResourceCalendar *r = resource( incidence );
   if ( !r ) {
-    r = mDestinationPolicy->destination( incidence );
+    r = d->mDestinationPolicy->destination( incidence );
     if ( !r ) {
-      kError() << "Unable to get destination resource." << endl;
+      kError() << "Unable to get destination resource.";
       return false;
     }
-    mResourceMap[ incidence ] = r;
+    d->mResourceMap[ incidence ] = r;
   }
 
   int count = incrementChangeCount( r );
   if ( count == 1 ) {
     Ticket *ticket = requestSaveTicket( r );
     if ( !ticket ) {
-      kDebug(5800) << "CalendarResources::beginChange(): unable to get ticket."
-                    << endl;
+      kDebug(5800) << "CalendarResources::beginChange(): unable to get ticket.";
       decrementChangeCount( r );
       return false;
     } else {
-      mTickets[ r ] = ticket;
+      d->mTickets[ r ] = ticket;
     }
   }
 
@@ -723,8 +841,6 @@ bool CalendarResources::beginChange( Incidence *incidence )
 
 bool CalendarResources::endChange( Incidence *incidence )
 {
-  kDebug(5800) << "CalendarResource::endChange()" << endl;
-
   ResourceCalendar *r = resource( incidence );
   if ( !r ) {
     return false;
@@ -733,9 +849,9 @@ bool CalendarResources::endChange( Incidence *incidence )
   int count = decrementChangeCount( r );
 
   if ( count == 0 ) {
-    bool ok = save( mTickets[ r ], incidence );
+    bool ok = save( d->mTickets[ r ], incidence );
     if ( ok ) {
-      mTickets.remove( r );
+      d->mTickets.remove( r );
     } else {
       return false;
     }
@@ -746,31 +862,31 @@ bool CalendarResources::endChange( Incidence *incidence )
 
 int CalendarResources::incrementChangeCount( ResourceCalendar *r )
 {
-  if ( !mChangeCounts.contains( r ) ) {
-    mChangeCounts.insert( r, 0 );
+  if ( !d->mChangeCounts.contains( r ) ) {
+    d->mChangeCounts.insert( r, 0 );
   }
 
-  int count = mChangeCounts[ r ];
+  int count = d->mChangeCounts[ r ];
   ++count;
-  mChangeCounts[ r ] = count;
+  d->mChangeCounts[ r ] = count;
 
   return count;
 }
 
 int CalendarResources::decrementChangeCount( ResourceCalendar *r )
 {
-  if ( !mChangeCounts.contains( r ) ) {
-    kError() << "No change count for resource." << endl;
+  if ( !d->mChangeCounts.contains( r ) ) {
+    kError() << "No change count for resource.";
     return 0;
   }
 
-  int count = mChangeCounts[ r ];
+  int count = d->mChangeCounts[ r ];
   --count;
   if ( count < 0 ) {
-    kError() << "Can't decrement change count. It already is 0." << endl;
+    kError() << "Can't decrement change count. It already is 0.";
     count = 0;
   }
-  mChangeCounts[ r ] = count;
+  d->mChangeCounts[ r ] = count;
 
   return count;
 }
@@ -786,18 +902,3 @@ void CalendarResources::slotSaveError( ResourceCalendar *r, const QString &err )
   Q_UNUSED( r );
   emit signalErrorMessage( err );
 }
-
-#include "calendarresources.moc"
-
-// DEPRECATED methods
-Alarm::List CalendarResources::alarmsTo( const QDateTime &to )
-{ return alarmsTo(KDateTime(to, timeSpec())); }
-
-bool CalendarResources::reload( const QString &tz )
-{
-  save();
-  close();
-  setTimeZoneId( tz );
-  load();
-  return true;
-}
