@@ -24,18 +24,22 @@
   This file is part of the API for handling calendar data and
   defines the Person class.
 
-  @author Cornelius Schumacher
-  @author Reinhold Kainhofer
+  @brief
+  Represents a person, by name and email address.
+
+  @author Cornelius Schumacher \<schumacher@kde.org\>
+  @author Reinhold Kainhofer \<reinhold@kainhofer.com\>
 */
 
-#include <QRegExp>
+#include "person.h"
+
+#include "kpimutils/email.h"
+
+#include <QtCore/QRegExp>
 
 #include <kdebug.h>
 #include <klocale.h>
 
-#include "emailfunctions/email.h"
-#include "person.h"
-
 using namespace KCal;
 
 /**
@@ -57,8 +61,7 @@ Person::Person() : d( new KCal::Person::Private )
 
 Person::Person( const QString &fullName ) : d( new KCal::Person::Private )
 {
-  EmailAddressTools::extractEmailAddressAndName( fullName,
-                                                 d->mEmail, d->mName );
+  KPIMUtils::extractEmailAddressAndName( fullName, d->mEmail, d->mName );
 }
 
 Person::Person( const QString &name, const QString &email )
@@ -68,10 +71,9 @@ Person::Person( const QString &name, const QString &email )
   d->mEmail = email;
 }
 
-Person::Person( const Person &person ) : d( new KCal::Person::Private )
+Person::Person( const Person &person )
+  : d( new KCal::Person::Private( *person.d ) )
 {
-    d->mName = person.d->mName;
-    d->mEmail = person.d->mEmail;
 }
 
 Person::~Person()
@@ -81,14 +83,14 @@ Person::~Person()
 
 bool KCal::Person::operator==( const Person &person )
 {
-  return ( d->mName == person.d->mName &&
-           d->mEmail == person.d->mEmail );
+  return
+    d->mName == person.d->mName &&
+    d->mEmail == person.d->mEmail;
 }
 
 Person &KCal::Person::operator=( const Person &person )
 {
-  d->mName = person.d->mName;
-  d->mEmail = person.d->mEmail;
+  *d = *person.d;
   return *this;
 }
 
