@@ -20,6 +20,7 @@
 */
 
 #include "resourcelocaldir.h"
+#include "resourcelocaldir_p.h"
 #include "calendarlocal.h"
 #include "incidence.h"
 #include "event.h"
@@ -30,7 +31,6 @@
 
 #include <kdebug.h>
 #include <klocale.h>
-#include <kurl.h>
 #include <kconfig.h>
 #include <kstandarddirs.h>
 #include <kconfiggroup.h>
@@ -66,7 +66,7 @@ ResourceLocalDir::ResourceLocalDir( const QString &dirName )
 
 void ResourceLocalDir::readConfig( const KConfigGroup &group )
 {
-  QString url = group.readPathEntry( "CalendarURL" );
+  QString url = group.readPathEntry( "CalendarURL", QString() );
   d->mURL = KUrl( url );
 }
 
