@@ -26,23 +26,21 @@
 #include <kcmdlineargs.h>
 
 #include "kcal/calendarlocal.h"
+#include "kcal/versit/vobject.h"
 
 using namespace KCal;
 
-static const KCmdLineOptions options[] =
-{
-  {"verbose", "Verbose output", 0},
-  KCmdLineLastOption
-};
-
 int main(int argc,char **argv)
 {
-  KAboutData aboutData("testcalendar","Test Calendar","0.1");
+  KAboutData aboutData("testcalendar", 0,ki18n("Test Calendar"),"0.1");
   KCmdLineArgs::init(argc,argv,&aboutData);
+
+  KCmdLineOptions options;
+  options.add("verbose", ki18n("Verbose output"));
   KCmdLineArgs::addCmdLineOptions( options );
 
   KComponentData componentData( &aboutData );
-  //QCoreApplication app( *KCmdLineArgs::qt_argc(), *KCmdLineArgs::qt_argv() );
+  //QCoreApplication app( KCmdLineArgs::qtArgc(), KCmdLineArgs::qtArgv() );
 
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
@@ -52,34 +50,36 @@ int main(int argc,char **argv)
 
   QString file = QLatin1String( INPUT );
   if (!cal.load( file ) ) {
-    kError() << "Can't load " << file << endl;
+    kError() << "Can't load" << file;
     return 1;
   }
 
   QString uid = QLatin1String("KOrganizer-1345486115.965");
   Event *e = cal.event( uid );
   if (!e) {
-    kError() << "No event " << uid << endl;
+    kError() << "No event" << uid;
     return 1;
   }
 
 /*  if (e->hasStartDate()) {
     KDateTime d = e->dtStart();
-    kDebug() << "Event starts " << d << endl;
+    kDebug() << "Event starts" << d;
   }
 */
 
-  kDebug() << "Event description " << e->summary() << endl;
+  kDebug() << "Event description" << e->summary();
 
   if (e->hasEndDate()) {
     KDateTime d = e->dtEnd();
-    kDebug() << "Event ends " << d << endl;
+    kDebug() << "Event ends" << d;
   }
 
-  if (e->pilotId()) {
-    kDebug() << "Pilot ID = " << e->pilotId() << endl;
+
+  QString pilotId = e->nonKDECustomProperty( KPilotIdProp );
+  if (!pilotId.isEmpty()) {
+    kDebug() << "Pilot ID =" << pilotId;
   } else {
-    kError() << "No Pilot ID" << endl;
+    kError() << "No Pilot ID";
     return 1;
   }
 
