@@ -41,14 +41,7 @@ extern "C" {
 
 static const int debugArea = 7122;
 
-static inline
-#ifdef NDEBUG
-  QDebug ksDebug() { return kDebug( debugArea ); }
-  QDebug ksDebug( bool cond ) { return kDebug( cond, debugArea ); }
-#else
-  QDebug ksDebug() { return kDebug( debugArea ); }
-  QDebug ksDebug( bool cond ) { return kDebug( cond, debugArea ); }
-#endif
+#define ksDebug         kDebug( debugArea )
 
 #define SIEVE_DEFAULT_PORT 2000
 
@@ -72,10 +65,10 @@ extern "C"
 	{
 		KComponentData instance("kio_sieve" );
 
-		ksDebug() << "*** Starting kio_sieve " << endl;
+		ksDebug << "*** Starting kio_sieve " << endl;
 
 		if (argc != 4) {
-			ksDebug() << "Usage: kio_sieve protocol domain-socket1 domain-socket2" << endl;
+			ksDebug << "Usage: kio_sieve protocol domain-socket1 domain-socket2" << endl;
 			return -1;
 		}
 
@@ -89,7 +82,7 @@ extern "C"
 
 		sasl_done();
 
-		ksDebug() << "*** kio_sieve Done" << endl;
+		ksDebug << "*** kio_sieve Done" << endl;
 		return 0;
 	}
 }
@@ -107,7 +100,7 @@ const uint& kio_sieveResponse::getType() const
 }
 
 /* ---------------------------------------------------------------------------------- */
-const uint kio_sieveResponse::getQuantity() const
+uint kio_sieveResponse::getQuantity() const
 {
 	return quantity;
 }
@@ -179,7 +172,7 @@ void kio_sieveResponse::clear()
 
 /* ---------------------------------------------------------------------------------- */
 kio_sieveProtocol::kio_sieveProtocol(const QByteArray &pool_socket, const QByteArray &app_socket)
-	: TCPSlaveBase( SIEVE_DEFAULT_PORT, "sieve", pool_socket, app_socket, false)
+	: TCPSlaveBase("sieve", pool_socket, app_socket, false)
 	, m_connMode(NORMAL)
 	, m_supportsTLS(false)
 	, m_shouldBeConnected(false)
@@ -189,14 +182,14 @@ kio_sieveProtocol::kio_sieveProtocol(const QByteArray &pool_socket, const QByteA
 /* ---------------------------------------------------------------------------------- */
 kio_sieveProtocol::~kio_sieveProtocol()
 {
-	if ( isConnectionValid() )
+	if ( isConnected() )
 		disconnect();
 }
 
 /* ---------------------------------------------------------------------------------- */
 void kio_sieveProtocol::setHost (const QString &host, quint16 port, const QString &user, const QString &pass)
 {
-	if ( isConnectionValid() &&
+	if ( isConnected() &&
 			( m_sServer != host ||
 				m_sPort != QString::number( port ) ||
 				m_sUser != user ||
@@ -204,7 +197,7 @@ void kio_sieveProtocol::setHost (const QString &host, quint16 port, const QStrin
 		disconnect();
 	}
 	m_sServer = host;
-	m_sPort = QString::number( port ? port : defaultPort() );
+	m_sPort = QString::number( port ? port : SIEVE_DEFAULT_PORT );
 	m_sUser = user;
 	m_sPass = pass;
 	m_supportsTLS = false;
@@ -219,7 +212,7 @@ void kio_sieveProtocol::openConnection()
 
 bool kio_sieveProtocol::parseCapabilities(bool requestCapabilities/* = false*/)
 {
-	ksDebug() << endl;
+	ksDebug << endl;
 
 	// Setup...
 	bool ret = false;
@@ -229,18 +222,18 @@ bool kio_sieveProtocol::parseCapabilities(bool requestCapabilities/* = false*/)
 	}
 
 	while (receiveData()) {
-		ksDebug() << "Looping receive" << endl;
+		ksDebug << "Looping receive" << endl;
 
 		if (r.getType() == kio_sieveResponse::ACTION) {
 			if ( r.getAction().toLower().contains("ok") ) {
-				ksDebug() << "Sieve server ready & awaiting authentication." << endl;
+				ksDebug << "Sieve server ready & awaiting authentication." << endl;
 				break;
 			} else
-				ksDebug() << "Unknown action " << r.getAction() << "." << endl;
+				ksDebug << "Unknown action " << r.getAction() << "." << endl;
 
 		} else if (r.getKey() == "IMPLEMENTATION") {
 			if (r.getVal().toLower().contains("sieve") ) {
-				ksDebug() << "Connected to Sieve server: " << r.getVal() << endl;
+				ksDebug << "Connected to Sieve server: " << r.getVal() << endl;
 				ret = true;
 				setMetaData("implementation", r.getVal());
 			}
@@ -248,22 +241,22 @@ bool kio_sieveProtocol::parseCapabilities(bool requestCapabilities/* = false*/)
 		} else if (r.getKey() == "SASL") {
 			// Save list of available SASL methods
 			m_sasl_caps = QString(r.getVal()).split(' ');
-			ksDebug() << "Server SASL authentication methods: " << m_sasl_caps.join(", ") << endl;
+			ksDebug << "Server SASL authentication methods: " << m_sasl_caps.join(", ") << endl;
 			setMetaData("saslMethods", r.getVal());
 
 		} else if (r.getKey() == "SIEVE") {
 			// Save script capabilities; report back as meta data:
-			ksDebug() << "Server script capabilities: " << QString(r.getVal()).split(' ').join(", ") << endl;
+			ksDebug << "Server script capabilities: " << QString(r.getVal()).split(' ').join(", ") << endl;
 			setMetaData("sieveExtensions", r.getVal());
 
 		} else if (r.getKey() == "STARTTLS") {
 			// The server supports TLS
-			ksDebug() << "Server supports TLS" << endl;
+			ksDebug << "Server supports TLS" << endl;
 			m_supportsTLS = true;
 			setMetaData("tlsSupported", "true");
 
 		} else {
-			ksDebug() << "Unrecognised key " << r.getKey() << endl;
+			ksDebug << "Unrecognised key " << r.getKey() << endl;
 		}
 	}
 
@@ -301,10 +294,10 @@ void kio_sieveProtocol::changeCheck( const KUrl &url )
 			}
 		}
 	}
-	ksDebug() << "auth: " << auth << " m_sAuth: " << m_sAuth << endl;
+	ksDebug << "auth: " << auth << " m_sAuth: " << m_sAuth << endl;
 	if ( m_sAuth != auth ) {
 		m_sAuth = auth;
-		if ( isConnectionValid() )
+		if ( isConnected() )
 			disconnect();
 	}
 }
@@ -316,9 +309,9 @@ void kio_sieveProtocol::changeCheck( const KUrl &url )
  */
 bool kio_sieveProtocol::connect(bool useTLSIfAvailable)
 {
-	ksDebug() << endl;
+	ksDebug << endl;
 
-	if (isConnectionValid()) return true;
+	if (isConnected()) return true;
 
 	infoMessage(i18n("Connecting to %1...", m_sServer));
 
@@ -327,40 +320,40 @@ bool kio_sieveProtocol::connect(bool useTLSIfAvailable)
 		return false;
 	}
 
-	setBlockConnection(true);
+	setBlocking(true);
 
 	if (!connectToHost(m_sServer, m_sPort, true)) {
 		return false;
 	}
 
 	if (!parseCapabilities()) {
-		closeDescriptor();
+		disconnectFromHost();
 		error(ERR_UNSUPPORTED_PROTOCOL, i18n("Server identification failed."));
 		return false;
 	}
 
 	// Attempt to start TLS
 	// FIXME find a test server and test that this works
-	if (useTLSIfAvailable && m_supportsTLS && canUseTLS()) {
+	// TODO ask the system whether SSL is available
+	if (useTLSIfAvailable && m_supportsTLS) {
 		sendData("STARTTLS");
 		if (operationSuccessful()) {
-			ksDebug() << "TLS has been accepted. Starting TLS..." << endl
-				  << "WARNING this is untested and may fail." << endl;
-			int retval = startTLS();
-			if (retval == 1) {
-				ksDebug() << "TLS enabled successfully." << endl;
+			ksDebug << "TLS has been accepted. Starting TLS..." << endl
+				      << "WARNING this is untested and may fail." << endl;
+			if (startSsl()) {
+				ksDebug << "TLS enabled successfully." << endl;
 				// reparse capabilities:
 				parseCapabilities(false);
 			} else {
-				ksDebug() << "TLS initiation failed, code " << retval << endl;
+				ksDebug << "TLS initiation failed." << endl;
 				disconnect(true);
 				return connect(false);
 				// error(ERR_INTERNAL, i18n("TLS initiation failed."));
 			}
 		} else
-			ksDebug() << "Server incapable of TLS. Transmitted documents will be unencrypted." << endl;
+			ksDebug << "Server incapable of TLS. Transmitted documents will be unencrypted." << endl;
 	} else
-		ksDebug() << "We are incapable of TLS. Transmitted documents will be unencrypted." << endl;
+		ksDebug << "We are incapable of TLS. Transmitted documents will be unencrypted." << endl;
 
 	infoMessage(i18n("Authenticating user..."));
 	if (!authenticate()) {
@@ -387,17 +380,17 @@ void kio_sieveProtocol::disconnect(bool forcibly)
 		sendData("LOGOUT");
 
 		if (!operationSuccessful())
-			ksDebug() << "Server did not logout cleanly." << endl;
+			ksDebug << "Server did not logout cleanly." << endl;
 	}
 
-	closeDescriptor();
+	disconnectFromHost();
 	m_shouldBeConnected = false;
 }
 
 /* ---------------------------------------------------------------------------------- */
 /*void kio_sieveProtocol::slave_status()
 {
-	slaveStatus(isConnectionValid() ? m_sServer : "", isConnectionValid());
+	slaveStatus(isConnected() ? m_sServer : "", isConnected());
 
 	finished();
 }*/
@@ -451,7 +444,7 @@ bool kio_sieveProtocol::activate(const KUrl& url)
 		return false;
 
 	if (operationSuccessful()) {
-		ksDebug() << "Script activation complete." << endl;
+		ksDebug << "Script activation complete." << endl;
 		return true;
 	} else {
 		error(ERR_INTERNAL_SERVER, i18n("There was an error activating the script."));
@@ -469,7 +462,7 @@ bool kio_sieveProtocol::deactivate()
 		return false;
 
 	if (operationSuccessful()) {
-		ksDebug() << "Script deactivation complete." << endl;
+		ksDebug << "Script deactivation complete." << endl;
 		return true;
 	} else {
 		error(ERR_INTERNAL_SERVER, i18n("There was an error deactivating the script."));
@@ -559,11 +552,11 @@ void kio_sieveProtocol::put(const KUrl& url, int /*permissions*/, KIO::JobFlags)
 		// with anything but OK we treat it as an error.
 		char * buf = new char[2];
 		while (!atEnd()) {
-			ksDebug() << "Reading..." << endl;
+			ksDebug << "Reading..." << endl;
 			read(buf, 1);
-			ksDebug() << "Trailing [" << buf[0] << "]" << endl;
+			ksDebug << "Trailing [" << buf[0] << "]" << endl;
 		}
-		ksDebug() << "End of data." << endl;
+		ksDebug << "End of data." << endl;
 		delete[] buf;
 
 		if (!operationSuccessful()) {
@@ -591,7 +584,7 @@ void kio_sieveProtocol::put(const KUrl& url, int /*permissions*/, KIO::JobFlags)
 	infoMessage(i18n("Verifying upload completion..."));
 
 	if (operationSuccessful())
-		ksDebug() << "Script upload complete." << endl;
+		ksDebug << "Script upload complete." << endl;
 
 	else {
 		/* The managesieve server parses received scripts and rejects
@@ -701,7 +694,7 @@ void kio_sieveProtocol::get(const KUrl& url)
 		  QByteArray dat( qMin( total_len - recv_len, ssize_t(64 * 1024 )), '\0' );
 		  ssize_t this_recv_len = read( dat.data(), dat.size() );
 
-		  if ( this_recv_len < 1 && !isConnectionValid() ) {
+		  if ( this_recv_len < 1 && !isConnected() ) {
 		    error( KIO::ERR_CONNECTION_BROKEN, m_sServer );
 		    disconnect( true );
 		    return;
@@ -720,9 +713,9 @@ void kio_sieveProtocol::get(const KUrl& url)
 		data(QByteArray());
 
 		if (operationSuccessful())
-			ksDebug() << "Script retrieval complete." << endl;
+			ksDebug << "Script retrieval complete." << endl;
 		else
-			ksDebug() << "Script retrieval failed." << endl;
+			ksDebug << "Script retrieval failed." << endl;
 	} else {
 		error(ERR_UNSUPPORTED_PROTOCOL, i18n("A protocol error occurred "
 							"while trying to negotiate script downloading."));
@@ -757,7 +750,7 @@ void kio_sieveProtocol::del(const KUrl &url, bool isfile)
 		return;
 
 	if (operationSuccessful())
-		ksDebug() << "Script deletion successful." << endl;
+		ksDebug << "Script deletion successful." << endl;
 	else {
 		error(ERR_INTERNAL_SERVER, i18n("The server would not delete the file."));
 		return;
@@ -873,7 +866,7 @@ void kio_sieveProtocol::listDir(const KUrl& url)
 
 			//asetMetaData("active", (r.getExtra() == "ACTIVE") ? "true" : "false");
 
-			ksDebug() << "Listing script " << r.getKey() << endl;
+			ksDebug << "Listing script " << r.getKey() << endl;
 			listEntry(entry , false);
 		}
 	}
@@ -886,7 +879,7 @@ void kio_sieveProtocol::listDir(const KUrl& url)
 /* ---------------------------------------------------------------------------------- */
 bool kio_sieveProtocol::saslInteract( void *in, AuthInfo &ai )
 {
-	ksDebug() << "sasl_interact" << endl;
+	ksDebug << "sasl_interact" << endl;
 	sasl_interact_t *interact = ( sasl_interact_t * ) in;
 
 	//some mechanisms do not require username && pass, so it doesn't need a popup
@@ -909,16 +902,16 @@ bool kio_sieveProtocol::saslInteract( void *in, AuthInfo &ai )
 
 	interact = ( sasl_interact_t * ) in;
 	while( interact->id != SASL_CB_LIST_END ) {
-		ksDebug() << "SASL_INTERACT id: " << interact->id << endl;
+		ksDebug << "SASL_INTERACT id: " << interact->id << endl;
 		switch( interact->id ) {
 			case SASL_CB_USER:
 			case SASL_CB_AUTHNAME:
-				ksDebug() << "SASL_CB_[AUTHNAME|USER]: '" << m_sUser << "'" << endl;
+				ksDebug << "SASL_CB_[AUTHNAME|USER]: '" << m_sUser << "'" << endl;
 				interact->result = strdup( m_sUser.toUtf8() );
 				interact->len = strlen( (const char *) interact->result );
 				break;
 			case SASL_CB_PASS:
-				ksDebug() << "SASL_CB_PASS: [hidden] " << endl;
+				ksDebug << "SASL_CB_PASS: [hidden] " << endl;
 				interact->result = strdup( m_sPass.toUtf8() );
 				interact->len = strlen( (const char *) interact->result );
 				break;
@@ -961,7 +954,7 @@ bool kio_sieveProtocol::authenticate()
 
 	result = sasl_client_new( "sieve", m_sServer.toLatin1(), 0, 0, callbacks, 0, &conn );
 	if ( result != SASL_OK ) {
-		ksDebug() << "sasl_client_new failed with: " << result << endl;
+		ksDebug << "sasl_client_new failed with: " << result << endl;
 		SASLERROR
 		return false;
 	}
@@ -986,13 +979,13 @@ bool kio_sieveProtocol::authenticate()
 	} while ( result == SASL_INTERACT );
 
 	if ( result != SASL_CONTINUE && result != SASL_OK ) {
-		ksDebug() << "sasl_client_start failed with: " << result << endl;
+		ksDebug << "sasl_client_start failed with: " << result << endl;
 		SASLERROR
 		sasl_dispose( &conn );
 		return false;
 	}
 
-	ksDebug() << "Preferred authentication method is " << mechusing << "." << endl;
+	ksDebug << "Preferred authentication method is " << mechusing << "." << endl;
 
 	QString firstCommand = "AUTHENTICATE \"" + QString::fromLatin1( mechusing ) + "\"";
 	challenge = QByteArray::fromRawData( out, outlen ).toBase64();
@@ -1002,7 +995,7 @@ bool kio_sieveProtocol::authenticate()
 		firstCommand += '\"';
 	}
 
-	ksDebug() << "firstCommand: " << firstCommand << endl;
+	ksDebug << "firstCommand: " << firstCommand << endl;
 	if (!sendData( firstCommand.toLatin1() ))
 		return false;
 
@@ -1012,7 +1005,7 @@ bool kio_sieveProtocol::authenticate()
 		if (operationResult() != OTHER)
 			break;
 
-		ksDebug() << "Challenge len  " << r.getQuantity() << endl;
+		ksDebug << "Challenge len  " << r.getQuantity() << endl;
 
 		if (r.getType() != kio_sieveResponse::QUANTITY) {
 			sasl_dispose( &conn );
@@ -1032,7 +1025,7 @@ bool kio_sieveProtocol::authenticate()
 			return false;
 		}
 		challenge = QByteArray::fromBase64( QByteArray::fromRawData( r.getAction().data(), qty ) );
-//		ksDebug() << "S:  [" << r.getAction() << "]." << endl;
+//		ksDebug << "S:  [" << r.getAction() << "]." << endl;
 
 		do {
 			result = sasl_client_step(conn, challenge.isEmpty() ? 0 : challenge.data(),
@@ -1045,19 +1038,19 @@ bool kio_sieveProtocol::authenticate()
 				};
 		} while ( result == SASL_INTERACT );
 
-		ksDebug() << "sasl_client_step: " << result << endl;
+		ksDebug << "sasl_client_step: " << result << endl;
 		if ( result != SASL_CONTINUE && result != SASL_OK ) {
-			ksDebug() << "sasl_client_step failed with: " << result << endl;
+			ksDebug << "sasl_client_step failed with: " << result << endl;
 			SASLERROR
 			sasl_dispose( &conn );
 			return false;
 		}
 
 		sendData('\"' + QByteArray::fromRawData( out, outlen ).toBase64() + '\"');
-//    ksDebug() << "C-1:  [" << out << "]." << endl;
+//    ksDebug << "C-1:  [" << out << "]." << endl;
 	} while ( true );
 
-	ksDebug() << "Challenges finished." << endl;
+	ksDebug << "Challenges finished." << endl;
 	sasl_dispose( &conn );
 
 	if (operationResult() == OK) {
@@ -1074,7 +1067,7 @@ bool kio_sieveProtocol::authenticate()
 /* --------------------------------------------------------------------------- */
 void kio_sieveProtocol::mimetype(const KUrl & url)
 {
-	ksDebug() << "Requesting mimetype for " << url.prettyUrl() << endl;
+	ksDebug << "Requesting mimetype for " << url.prettyUrl() << endl;
 
 	if (url.fileName(false).isEmpty())
 		mimeType( "inode/directory" );
@@ -1090,7 +1083,7 @@ bool kio_sieveProtocol::sendData(const QByteArray &data)
 {
 	QByteArray write_buf = data + "\r\n";
 
-	//ksDebug() << "C: " << data << endl;
+	//ksDebug << "C: " << data << endl;
 
 	// Write the command
 	ssize_t write_buf_len = write_buf.length();
@@ -1128,7 +1121,7 @@ bool kio_sieveProtocol::receiveData(bool waitForData, const QByteArray &reparse)
 
 	r.clear();
 
-	//ksDebug() << "S: " << interpret << endl;
+	//ksDebug << "S: " << interpret << endl;
 
 	switch(interpret[0]) {
 		case '{':
@@ -1160,7 +1153,7 @@ bool kio_sieveProtocol::receiveData(bool waitForData, const QByteArray &reparse)
 
 	end = interpret.indexOf('"', start + 1);
 	if (end == -1) {
-		ksDebug() << "Possible insufficient buffer size." << endl;
+		ksDebug << "Possible insufficient buffer size." << endl;
 		r.setKey(interpret.right(interpret.length() - start));
 		return true;
 	}
@@ -1178,7 +1171,7 @@ bool kio_sieveProtocol::receiveData(bool waitForData, const QByteArray &reparse)
 
 	end = interpret.indexOf('"', start + 1);
 	if (end == -1) {
-		ksDebug() << "Possible insufficient buffer size." << endl;
+		ksDebug << "Possible insufficient buffer size." << endl;
 		r.setVal(interpret.right(interpret.length() - start));
 		return true;
 	}
