@@ -18,10 +18,10 @@
   Boston, MA 02110-1301, USA.
 */
 
-#include <kdebug.h>
-
 #include "ldif.h"
 
+#include <kdebug.h>
+
 using namespace KLDAP;
 
 class Ldif::LdifPrivate
@@ -29,7 +29,8 @@ class Ldif::LdifPrivate
   public:
     int mModType;
     bool mDelOldRdn, mUrl;
-    QString mDn, mAttr, mNewRdn, mNewSuperior, mOid;
+    LdapDN mDn;
+    QString mAttr, mNewRdn, mNewSuperior, mOid;
     QByteArray mLdif, mValue;
     EntryType mEntryType;
 
@@ -39,14 +40,12 @@ class Ldif::LdifPrivate
     QByteArray mLine;
 };
 
-Ldif::Ldif()
-  : d( new LdifPrivate )
+Ldif::Ldif() : d( new LdifPrivate )
 {
   startParsing();
 }
 
-Ldif::Ldif( const Ldif &that )
-  : d( new LdifPrivate )
+Ldif::Ldif( const Ldif &that ) : d( new LdifPrivate )
 {
   *d = *that.d;
 
@@ -132,14 +131,14 @@ bool Ldif::splitLine( const QByteArray &line, QString &fieldname, QByteArray &va
   QByteArray tmp;
   int linelen;
 
-//  kDebug(5700) << "splitLine line: " << QString::fromUtf8(line) << endl;
+//  kDebug(5322) << "splitLine line:" << QString::fromUtf8(line);
 
   position = line.indexOf( ":" );
   if ( position == -1 ) {
     // strange: we did not find a fieldname
     fieldname = "";
     value = line.trimmed();
-//    kDebug(5700) << "value : " << value[0] << endl;
+//    kDebug(5322) << "value :" << value[0];
     return false;
   }
 
@@ -181,7 +180,7 @@ bool Ldif::splitControl( const QByteArray &line, QString &oid, bool &critical,
   critical = false;
   bool url = splitLine( line, tmp, value );
 
-  kDebug(5700) << "splitControl: value: " << QString::fromUtf8(value, value.size()) << endl;
+  kDebug(5322) << "splitControl: value:" << QString::fromUtf8(value, value.size());
   if ( tmp.isEmpty() ) {
     tmp = QString::fromUtf8( value, value.size() );
     value.resize( 0 );
@@ -220,8 +219,8 @@ Ldif::ParseValue Ldif::processLine()
         retval = Err;
       }
     } else if ( attrLower == "dn" ) {
-      kDebug(5700) << "ldapentry dn: " << QString::fromUtf8( d->mValue, d->mValue.size() ) << endl;
-      d->mDn = QString::fromUtf8( d->mValue, d->mValue.size() );
+      kDebug(5322) << "ldapentry dn:" << QString::fromUtf8( d->mValue, d->mValue.size() );
+      d->mDn = LdapDN( QString::fromUtf8( d->mValue, d->mValue.size() ) );
       d->mModType = Mod_None;
       retval = NewEntry;
     } else if ( attrLower == "changetype" ) {
@@ -229,7 +228,7 @@ Ldif::ParseValue Ldif::processLine()
         retval = Err;
       } else {
         QString tmpval = QString::fromUtf8( d->mValue, d->mValue.size() );
-        kDebug(5700) << "changetype: " << tmpval << endl;
+        kDebug(5322) << "changetype:" << tmpval;
         if ( tmpval == "add" ) {
           d->mEntryType = Entry_Add;
         } else if ( tmpval == "delete" ) {
@@ -269,7 +268,7 @@ Ldif::ParseValue Ldif::processLine()
     break;
   case Entry_Mod:
     if ( d->mModType == Mod_None ) {
-      kDebug(5700) << "kio_ldap: new modtype " << d->mAttr << endl;
+      kDebug(5322) << "kio_ldap: new modtype" << d->mAttr;
       if ( d->mAttr.isEmpty() && d->mValue.size() == 0 ) {
         retval = EndEntry;
       } else if ( attrLower == "add" ) {
@@ -277,12 +276,12 @@ Ldif::ParseValue Ldif::processLine()
       } else if ( attrLower == "replace" ) {
         d->mModType = Mod_Replace;
         d->mAttr = QString::fromUtf8( d->mValue, d->mValue.size() );
-        d->mValue.resize( 0 );
+        d->mValue = QByteArray();
         retval = Item;
       } else if ( attrLower == "delete" ) {
         d->mModType = Mod_Del;
         d->mAttr = QString::fromUtf8( d->mValue, d->mValue.size() );
-        d->mValue.resize( 0 );
+        d->mValue = QByteArray();
         retval = Item;
       } else {
         retval = Err;
@@ -377,7 +376,8 @@ void Ldif::startParsing()
   d->mDelOldRdn = false;
   d->mEntryType = Entry_None;
   d->mModType = Mod_None;
-  d->mDn = d->mNewRdn = d->mNewSuperior = QString();
+  d->mDn = LdapDN();
+  d->mNewRdn = d->mNewSuperior = QString();
   d->mLine = QByteArray();
   d->mIsNewLine = false;
   d->mIsComment = false;
@@ -400,7 +400,7 @@ int Ldif::modType() const
   return d->mModType;
 }
 
-QString Ldif::dn() const
+LdapDN Ldif::dn() const
 {
   return d->mDn;
 }
