@@ -95,6 +95,7 @@ void Identity::readConfig( const KConfigGroup &config )
     mPropertiesMap.insert( i.key(), i.value() );
     ++i;
   }
+  mSignature.readConfig( config );
 }
 
 void Identity::writeConfig( KConfigGroup &config ) const
@@ -235,7 +236,8 @@ bool Identity::operator>= ( const Identity &other ) const
 
 bool Identity::operator== ( const Identity &other ) const
 {
-  return mPropertiesMap == other.mPropertiesMap;
+  return mPropertiesMap == other.mPropertiesMap &&
+         mSignature == other.mSignature;
 }
 
 bool Identity::operator!= ( const Identity &other ) const
@@ -292,30 +294,7 @@ QString Identity::identityName() const
 
 QString Identity::signatureText( bool *ok ) const
 {
-  bool internalOK = false;
-  QString signatureText = mSignature.withSeparator( &internalOK );
-  if ( internalOK ) {
-    if ( ok ) {
-      *ok = true;
-    }
-    return signatureText;
-  }
-
-  // OK, here comes the funny part. The call to
-  // Signature::withSeparator() failed, so we should probably fix the
-  // cause:
-  if ( ok ) {
-    *ok = false;
-  }
-  return QString();
-
-#if 0 // TODO: error handling
-  if ( mSignatureFile.endsWith( '|' ) ) {
-  } else {
-  }
-#endif
-
-  return QString();
+  return mSignature.withSeparator( ok );
 }
 
 bool Identity::isDefault() const
