@@ -126,6 +126,11 @@ class Manager : private ManagerNotifier
         Resource::List::Iterator mIt;
     };
 
+    /**
+      Typedef for STL style iterator
+     */
+    typedef Iterator iterator;
+
     /**
       Return Iterator on first resource. If there is no resource returns end().
     */
