@@ -28,13 +28,13 @@
  * @author Michael Goffioul
  */
 
-#include <QBuffer>
-#include <QList>
-
 #include "ktnefmessage.h"
 #include "ktnefattach.h"
 #include "lzfu.h"
 
+#include <QtCore/QBuffer>
+#include <QtCore/QList>
+
 using namespace KTnef;
 
 /**
