@@ -1,7 +1,7 @@
 /*
  * This file is part of the syndication library
  *
- * Copyright (C) 2006 Frank Osterfeld <frank.osterfeld@kdemail.net>
+ * Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -25,23 +25,21 @@
 
 #include <syndication/rdf/resourcewrapper.h>
 
-#include <specificdocument.h>
+#include <syndication/specificdocument.h>
 
 template <class T> class QList;
 
 namespace Syndication {
 namespace RDF {
 
-class Content;
 class Document;
 class DublinCore;
 class Image;
 class Item;
-class Model;
 class SyndicationInfo;
 class TextInput;
 //@cond PRIVATE
-typedef SharedPtr<Document> DocumentPtr;
+typedef boost::shared_ptr<Document> DocumentPtr;
 //@endcond
 
 /**
