@@ -1,7 +1,7 @@
 /*
  * This file is part of the syndication library
  *
- * Copyright (C) 2006 Frank Osterfeld <frank.osterfeld@kdemail.net>
+ * Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -20,16 +20,16 @@
  *
  */
 
+#include "resource.h"
 #include "model.h"
 #include "nodevisitor.h"
 #include "property.h"
-#include "resource.h"
 #include "statement.h"
 
 #include <krandom.h>
 
-#include <QList>
-#include <QString>
+#include <QtCore/QList>
+#include <QtCore/QString>
 
 namespace Syndication {
 namespace RDF {
@@ -57,7 +57,7 @@ Resource::Resource(const Resource& other) : Node(other)
     *this = other;
 }
 
-Resource::Resource() : d(0)
+Resource::Resource() : d()
 {
 }
 
@@ -125,7 +125,7 @@ Resource* Resource::clone() const
 
 void Resource::accept(NodeVisitor* visitor, NodePtr ptr)
 {
-    ResourcePtr rptr = ptr;
+    ResourcePtr rptr = boost::static_pointer_cast<Resource>(ptr);
     if (!visitor->visitResource(rptr))
         Node::accept(visitor, ptr);
 }
