@@ -1,7 +1,7 @@
 /*
  * This file is part of the syndication library
  *
- * Copyright (C) 2006 Frank Osterfeld <frank.osterfeld@kdemail.net>
+ * Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -24,10 +24,10 @@
 #define SYNDICATION_TOOLS_H
 
 #include <syndication/person.h>
-#include "ksyndication.h"
+#include "ksyndication_export.h"
 
 
-#include <QString>
+#include <QtCore/QString>
 
 #include <ctime>
 
